SystemOrganization addCategory: #ConfigurationOfSmallapack!

Object subclass: #ConfigurationOfSmallapack
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSmallapack'!

!ConfigurationOfSmallapack commentStamp: 'nice 7/30/2016 01:38' prior: 0!
ConfigurationOfSmallapack contains specification for loading the Smallapack - Lapack for Smalltalk.
See https://github.com/nicolas-cellier-aka-nice/smallapack/wiki

This Configuration is replicated into several repositories, currently:
http://www.squeaksource.com/MetacelloRepository
http://www.squeaksource.com/Smallapack

It might also be present in Pharo specific directory like:
http://smalltalkhub.com/mc/Pharo/MetaRepoForPharo30/main/
http://smalltalkhub.com/mc/Pharo/MetaRepoForPharo40/main/

!

!ConfigurationOfSmallapack class methodsFor: 'development support' stamp: 'nice 11/16/2011 23:09'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfSmallapack class methodsFor: 'private' stamp: 'nice 1/28/2012 18:17'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].! !

!ConfigurationOfSmallapack class methodsFor: 'private' stamp: 'nice 1/28/2012 23:42'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := (MCCacheRepository default includesVersionNamed: aString)
		ifTrue: [MCCacheRepository default]
		ifFalse: [MCHttpRepository
				location: aPath
				user: ''
				password: ''].
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSmallapack class methodsFor: 'catalog' stamp: 'nice 1/9/2019 11:57'!
catalogChangeLog
	"Returns a paragraph describing the most important changes in the configuration class."
	^ '- 1.0 - 2011/11/16 - initial version with Compiler overrides for Pharo1.0
[[[
	( ConfigurationOfSmallapack project version: ''1.0'' ) load.					
]]]
- 1.1 - 2012/08/03 - Use Smallapack-Compiler rather than overrides
[[[
	( ConfigurationOfSmallapack project version: ''1.1'' ) load.					
]]]
- 1.2 - 2014/03/19 - Make version work on Pharo2.0
[[[
	( ConfigurationOfSmallapack project version: ''1.2'' ) load.					
]]]
- 1.3 - 2016/07/30 - Library names are in Squeak Preferences
[[[
	( ConfigurationOfSmallapack project version: ''1.3'' ) load.					
]]]
- 1.4 - 2016/08/12 - Fix least squares
[[[
	( ConfigurationOfSmallapack project version: ''1.4'' ) load.					
]]]'! !

!ConfigurationOfSmallapack class methodsFor: 'catalog' stamp: 'nice 7/30/2016 01:56'!
catalogContactInfo
	"Returns a paragraph describing contact information such as email, mailing lists and website."
	^ 'Smallapack is maintained on github at https://github.com/nicolas-cellier-aka-nice/smallapack/ . Author can be reached at nicolas.cellier.aka.nice@gmail.com'! !

!ConfigurationOfSmallapack class methodsFor: 'catalog' stamp: 'nice 7/30/2016 01:54'!
catalogDescription
	"Returns a paragraph describing the project"
	^ 'Smallapack package bring the famous Linera Algebra PACKage from netlib in Smalltalk. See https://github.com/nicolas-cellier-aka-nice/smallapack/wiki for more information.'! !

!ConfigurationOfSmallapack class methodsFor: 'catalog' stamp: 'nice 7/30/2016 01:52'!
catalogKeyClassesAndExample
	"Returns a paragraph or more describing the key classes of your project. You can use Pillar/Pier syntax to layout out the text i.e., ==Code== and - for bullet."
	^ 'Smallapack has for main class ==LapackMatrix==.
Its subclasses are specializations for different matrix properties, storage, and contents type (real, complex, single double precision)
The other classes of importance are algorithms ==LapackDecomposition==.
Its subclasses are for solving linear systems, least square problems, eigen values problems, etc....
Some tutorial can be found on github wiki https://github.com/nicolas-cellier-aka-nice/smallapack/wiki/Tutorial_MatrixCreation'! !

!ConfigurationOfSmallapack class methodsFor: 'catalog' stamp: 'nice 7/30/2016 01:45'!
catalogKeywords
	"Returns an array of symbols"
	^ #(math matrix complex float lapack blas algebra) ! !

!ConfigurationOfSmallapack class methodsFor: 'development support' stamp: 'nice 11/16/2011 23:24'!
copyToGemSource
	"Copy the current configuration mcz file to http://seaside.gemstone.com/ss/MetacelloRepository"

	"Note you before copying config to GemSource, you should have tested the release in GLASS.
	 You also need to have commit rights to the GemSource repository."

	"self copyToGemSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://seaside.gemstone.com/ss/MetacelloRepository'! !

!ConfigurationOfSmallapack class methodsFor: 'development support' stamp: 'nice 11/16/2011 23:24'!
copyToSqueakSource
	"Copy the current configuration mcz file to http://www.squeaksource.com/MetacelloRepository"

	"self copyToSqueakSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://www.squeaksource.com/MetacelloRepository'! !

!ConfigurationOfSmallapack class methodsFor: 'private' stamp: 'nice 11/16/2011 23:11'!
ensureMetacello
	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfSmallapack class methodsFor: 'private' stamp: 'nice 1/28/2012 23:42'!
ensureMetacelloBaseConfiguration
	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self bootstrapPackage: 'Metacello-Base-DaleHenrichs.19' from: 'http://seaside.gemstone.com/ss/metacello']! !

!ConfigurationOfSmallapack class methodsFor: 'metacello tool support' stamp: 'nice 11/16/2011 23:10'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSmallapack class methodsFor: 'metacello tool support' stamp: 'nice 11/16/2011 23:14'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSmallapack class methodsFor: 'loading' stamp: 'nice 11/16/2011 23:10'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfSmallapack class methodsFor: 'loading' stamp: 'nice 11/16/2011 23:10'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfSmallapack class methodsFor: 'loading' stamp: 'nice 11/16/2011 23:10'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfSmallapack class methodsFor: 'loading' stamp: 'nice 11/16/2011 23:22'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfSmallapack class methodsFor: 'metacello tool support' stamp: 'nice 11/16/2011 23:14'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSmallapack class methodsFor: 'accessing' stamp: 'nice 11/16/2011 23:09'!
project
	^self new project! !

!ConfigurationOfSmallapack class methodsFor: 'unloading metacello' stamp: 'nice 11/16/2011 23:15'!
unloadMetacello
	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfSmallapack class methodsFor: 'development support' stamp: 'nice 11/16/2011 23:23'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: '- latest mcz files for 1.0.4'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfSmallapack class methodsFor: 'development support' stamp: 'nice 11/16/2011 23:09'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfSmallapack methodsFor: 'baselines' stamp: 'nice 3/8/2012 00:31'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/Smallapack'.
		spec 
			package: 'Smallapack-Collection' "with: [
				spec requires: #('Compiler' )]";
			package: 'Smallapack-External' with: [
				spec requires: #('Smallapack-Collection' )];
			package: 'Smallapack-Matrix' with: [
				spec requires: #('Smallapack-External' ). ];
			package: 'Smallapack-Algorithm' with: [
				spec requires: #('Smallapack-Matrix' ). ];
			package: 'Smallapack-SUnitTests' with: [
				spec requires: #('Smallapack-Algorithm' ). ]].
	spec for: #'squeak' do: [
		spec  preLoadDoIt: #preLoadSqueakCompilerOverride10.
		"spec repository: 'http://www.squeaksource.com/Smallapack'.
		spec 
			package: 'Compiler'"].
	spec for: #'pharo' do: [
		spec preLoadDoIt: #preLoadPharo14CompilerOverride10.
		spec project: 'Complex'
			with: [
				spec
					className: 'ConfigurationOfComplex';
					versionString: '1.0';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		"spec repository: 'http://www.squeaksource.com/Smallapack'.
		spec 
			package: 'Compiler'"].


! !

!ConfigurationOfSmallapack methodsFor: 'baselines' stamp: 'nice 3/19/2014 23:01'!
baseline11: spec
	<version: '1.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/Smallapack'.
		spec 
			package: 'Smallapack-Compiler';
			package: 'Smallapack-Collection' with: [
				spec requires: #('FFI' )];
			package: 'Smallapack-ExternalPrereq' with: [
				spec requires: #('Smallapack-Collection' )];
			package: 'Smallapack-External' with: [
				spec requires: #('Smallapack-ExternalPrereq' )];
			package: 'Smallapack-Matrix' with: [
				spec requires: #('Smallapack-External' ). ];
			package: 'Smallapack-AlgorithmPrereq' with: [
				spec requires: #('Smallapack-Compiler' ). ];
			package: 'Smallapack-Algorithm' with: [
				spec requires: #('Smallapack-Matrix' 'Smallapack-AlgorithmPrereq'). ];
			package: 'Smallapack-SUnitTests' with: [
				spec requires: #('Smallapack-Algorithm' ) ]. 
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #(
				'Smallapack-Compiler' 'Smallapack-Collection'
				'Smallapack-ExternalPrereq' 'Smallapack-External'
				'Smallapack-Matrix' 'Smallapack-Algorithm');
			group: 'Tests' with: #('Smallapack-SUnitTests') ;
			yourself].
	spec for: #'squeak' do: [
		spec 
			package: 'Math-Complex-Extensions';
			package: 'Smallapack-Matrix' with: [
				spec requires: #('Smallapack-External'  'Math-Complex-Extensions') ].
		spec project: 'FFI'
			with: [
				spec
					className: 'ConfigurationOfFFI';
					versionString: '1.5';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.].
	spec for: #'pharo' do: [
		spec
			package: 'Smallapack-Collection' with: [
				spec requires: #('Complex' )].
		spec project: 'FFI'
			with: [
				spec
					className: 'ConfigurationOfFFI';
					versionString: '1.5';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec project: 'Complex'
			with: [
				spec
					className: 'ConfigurationOfComplex';
					versionString: '1.0';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.].


! !

!ConfigurationOfSmallapack methodsFor: 'baselines' stamp: 'nice 1/9/2019 13:57'!
baseline12: spec
	<version: '1.2-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/Smallapack'.
		spec 
			package: 'Smallapack-Compiler';
			package: 'Smallapack-Collection' with: [
				spec requires: #('FFI' )];
			package: 'Smallapack-ExternalPrereq' with: [
				spec requires: #('Smallapack-Collection' )];
			package: 'Smallapack-External' with: [
				spec requires: #('Smallapack-ExternalPrereq' 'Smallapack-Compiler')];
			package: 'Smallapack-Matrix' with: [
				spec requires: #('Smallapack-External' ). ];
			package: 'Smallapack-AlgorithmPrereq' with: [
				spec requires: #('Smallapack-Compiler' ). ];
			package: 'Smallapack-Algorithm' with: [
				spec requires: #('Smallapack-Matrix' 'Smallapack-AlgorithmPrereq'). ];
			package: 'Smallapack-SUnitTests' with: [
				spec requires: #('Smallapack-Algorithm' ) ]. 
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #(
				'Smallapack-Compiler' 'Smallapack-Collection'
				'Smallapack-ExternalPrereq' 'Smallapack-External'
				'Smallapack-Matrix' 'Smallapack-AlgorithmPrereq' 'Smallapack-Algorithm');
			group: 'Tests' with: #('Smallapack-SUnitTests') ;
			yourself].
	spec for: #'squeak' do: [
		spec 
			package: 'Math-Complex-Extensions';
			package: 'Smallapack-Matrix' with: [
				spec requires: #('Smallapack-External'  'Math-Complex-Extensions') ].
		spec project: 'FFI'
			with: [
				spec
					className: 'ConfigurationOfFFI';
					versionString: '1.5';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.].
	spec for: #'pharo' do: [
		spec
			package: 'Smallapack-Collection' with: [
				spec requires: #('Complex' )].
		spec project: 'FFI'
			with: [
				spec
					className: 'ConfigurationOfFFI';
					versionString: '1.7';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec project: 'Complex'
			with: [
				spec
					className: 'ConfigurationOfComplex';
					versionString: '1.1';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.].
	spec for: #'pharo3.0.x' do: [
		spec
			package: 'Smallapack-CompilerPharo3Patch' with: [
				spec requires: #('Smallapack-Compiler' ). ];
			package: 'Smallapack-External' with: [
				spec requires: #('Smallapack-ExternalPrereq' 'Smallapack-CompilerPharo3Patch' ). ].
		spec project: 'FFI'
			with: [
				spec
					className: 'ConfigurationOfFFI';
					versionString: '1.8';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.].
	spec for: #'pharo4.0.x' do: [
		spec
			package: 'Smallapack-CompilerPharo3Patch' with: [
				spec requires: #('Smallapack-Compiler' ). ];
			package: 'Smallapack-External' with: [
				spec requires: #('Smallapack-ExternalPrereq' 'Smallapack-CompilerPharo3Patch' ). ].
		spec project: 'FFI'
			with: [
				spec
					className: 'ConfigurationOfFFI';
					versionString: '1.9';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.].
	spec for: #'pharo5.0.x' do: [
		spec
			package: 'Smallapack-CompilerPharo3Patch' with: [
				spec requires: #('Smallapack-Compiler' ). ];
			package: 'Smallapack-EndianPharo5Patch';
			package: 'Smallapack-External' with: [
				spec requires: #('Smallapack-ExternalPrereq' 'Smallapack-CompilerPharo3Patch' 'Smallapack-EndianPharo5Patch'). ].
		spec project: 'FFI'
			with: [
				spec
					className: 'ConfigurationOfFFI';
					versionString: '1.10.1';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.].


! !

!ConfigurationOfSmallapack methodsFor: 'baselines' stamp: 'nice 3/10/2017 00:58'!
baseline15: spec
	<version: '1.5-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/Smallapack'.
		spec 
			package: 'Smallapack-Compiler';
			package: 'Smallapack-Collection' with: [
				spec requires: #('FFI' )];
			package: 'Smallapack-ExternalPrereq' with: [
				spec requires: #('Smallapack-Collection' )];
			package: 'Smallapack-External' with: [
				spec requires: #('Smallapack-ExternalPrereq' 'Smallapack-Compiler')];
			package: 'Smallapack-Matrix' with: [
				spec requires: #('Smallapack-External' ). ];
			package: 'Smallapack-AlgorithmPrereq' with: [
				spec requires: #('Smallapack-Compiler' ). ];
			package: 'Smallapack-Algorithm' with: [
				spec requires: #('Smallapack-Matrix' 'Smallapack-AlgorithmPrereq'). ];
			package: 'Smallapack-SUnitTests' with: [
				spec requires: #('Smallapack-Algorithm' ) ]. 
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #(
				'Smallapack-Compiler' 'Smallapack-Collection'
				'Smallapack-ExternalPrereq' 'Smallapack-External'
				'Smallapack-Matrix' 'Smallapack-AlgorithmPrereq' 'Smallapack-Algorithm');
			group: 'Tests' with: #('Smallapack-SUnitTests') ;
			yourself].
	spec for: #'squeak' do: [
		spec 
			package: 'Math-Complex-Extensions';
			package: 'Smallapack-External' with: [
				spec requires: #('Alien' 'Smallapack-ExternalPrereq' 'Smallapack-Compiler')];
			package: 'Smallapack-Matrix' with: [
				spec requires: #('Smallapack-External'  'Math-Complex-Extensions') ].
		spec project: 'FFI'
			with: [
				spec
					className: 'ConfigurationOfFFI';
					versionString: '1.11';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec project: 'Alien'
			with: [
				spec
					className: 'ConfigurationOfOldAlien';
					versionString: '1.3';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.].
	spec for: #'pharo' do: [
		spec
			package: 'Smallapack-Collection' with: [
				spec requires: #('Complex' )].
		spec project: 'FFI'
			with: [
				spec
					className: 'ConfigurationOfFFI';
					versionString: '1.7';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec project: 'Complex'
			with: [
				spec
					className: 'ConfigurationOfComplex';
					versionString: '1.1';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.].
	spec for: #'pharo3.0.x' do: [
		spec
			package: 'Smallapack-CompilerPharo3Patch' with: [
				spec requires: #('Smallapack-Compiler' ). ];
			package: 'Smallapack-External' with: [
				spec requires: #('Smallapack-ExternalPrereq' 'Smallapack-CompilerPharo3Patch' ). ].
		spec project: 'FFI'
			with: [
				spec
					className: 'ConfigurationOfFFI';
					versionString: '1.8';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.].


! !

!ConfigurationOfSmallapack methodsFor: 'symbolic versions' stamp: 'nice 8/12/2016 23:50'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.4'! !

!ConfigurationOfSmallapack methodsFor: 'doIts' stamp: 'nice 3/8/2012 00:50'!
postLoadInitialization
	"Maybe this could be performed by Monticello, but MC initialization order is hard to manage."
	
	Smalltalk at: #LapackMatrix
		ifPresent: [:aClass |
			aClass initialize.
			(aClass allSubclasses select: [:e | e class selectors includes: #initialize]) do: [:e | e initialize]].! !

!ConfigurationOfSmallapack methodsFor: 'doIts' stamp: 'nice 3/8/2012 00:29'!
preLoadPharo14CompilerOverride10
	"Version 1.0 of Smallapack did require Compiler override.
	In version 1.1 overrides have been replaced by using a specific SmallapackCompiler."
	
	Gofer new
		squeaksource: 'Smallapack';
		project: 'Compiler.Pharo14';
		merge! !

!ConfigurationOfSmallapack methodsFor: 'doIts' stamp: 'nice 3/8/2012 00:29'!
preLoadSqueakCompilerOverride10
	"Version 1.0 of Smallapack did require Compiler override.
	In version 1.1 overrides have been replaced by using a specific SmallapackCompiler."
	
	Gofer new
		squeaksource: 'Smallapack';
		project: 'Compiler.trunk';
		merge! !

!ConfigurationOfSmallapack methodsFor: 'accessing' stamp: 'nice 11/16/2011 23:27'!
project

	^ project ifNil: [ | projectAttributes |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		project := (Smalltalk at: #MetacelloMCProject) new.
		projectAttributes := #().
		"Smalltalk at: #SystemVersion ifPresent: [:cl | | versionString |
			versionString := cl current version.
			((versionString beginsWith: 'Pharo-1.0') or: [versionString beginsWith: 'PharoCore1.0'])
				ifTrue: [ projectAttributes := projectAttributes, #() ] ]."
		project projectAttributes:  projectAttributes.
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear ]! !

!ConfigurationOfSmallapack methodsFor: 'symbolic versions' stamp: 'nice 3/10/2017 21:21'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.4'.
	spec for: #'squeak' version: '1.5'! !

!ConfigurationOfSmallapack methodsFor: 'versions' stamp: 'nice 3/8/2012 22:19'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'initial version with Compiler overrides'.
		spec author: 'nice'.
		spec timestamp: '11/16/2011 23:03'.
		spec 
			package: 'Smallapack-Collection' with: 'Smallapack-Collection-nice.14';
			package: 'Smallapack-External' with: 'Smallapack-External-nice.20';
			package: 'Smallapack-Matrix' with: 'Smallapack-Matrix-nice.25';
			package: 'Smallapack-Algorithm' with: 'Smallapack-Algorithm-nice.8';
			package: 'Smallapack-SUnitTests' with: 'Smallapack-SUnitTests-nice.10'.].
		spec for: #squeak do:[
			spec
			package: 'Compiler' with: 'Compiler.trunk-nice.222'. ].
		spec for: #pharo do:[
			spec
			package: 'Compiler' with: 'Compiler.Pharo14-nice.305'. ].
! !

!ConfigurationOfSmallapack methodsFor: 'versions' stamp: 'nice 3/8/2012 22:19'!
version11: spec
	<version: '1.1' imports: #('1.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Use Smallapack-Compiler rather than overrides'.
		spec author: 'nice'.
		spec timestamp: '03/08/2012 22:19'.
		spec 
			package: 'Smallapack-Collection' with: 'Smallapack-Collection-nice.14';
			package: 'Smallapack-ExternalPrereq' with: 'Smallapack-ExternalPrereq-nice.1';
			package: 'Smallapack-External' with: 'Smallapack-External-nice.22';
			package: 'Smallapack-Matrix' with: 'Smallapack-Matrix-nice.26';
			package: 'Smallapack-AlgorithmPrereq' with: 'Smallapack-AlgorithmPrereq-nice.1';
			package: 'Smallapack-Algorithm' with: 'Smallapack-Algorithm-nice.9';
			package: 'Smallapack-SUnitTests' with: 'Smallapack-SUnitTests-nice.12'.].
	spec for: #squeak do: [
		spec
			package: 'Math-Complex-Extensions' with: 'Math-Complex-Extensions-nice.8';
			package: 'Smallapack-Compiler' with:  'Smallapack-Compiler.trunk-nice.6'.
		spec postLoadDoIt: #postLoadInitialization].
	spec for: #pharo do: [
		spec
			package: 'Smallapack-Compiler' with: 'Smallapack-Compiler-nice.5'.
		spec postLoadDoIt: #postLoadInitialization].! !

!ConfigurationOfSmallapack methodsFor: 'versions' stamp: 'nice 3/20/2014 21:53'!
version12: spec
	<version: '1.2' imports: #('1.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Make version work on Pharo2.0'.
		spec author: 'nice'.
		spec timestamp: '19/03/2014 23:45'.
		spec 
			package: 'Smallapack-Collection' with: 'Smallapack-Collection-nice.15';
			package: 'Smallapack-ExternalPrereq' with: 'Smallapack-ExternalPrereq-nice.3';
			package: 'Smallapack-External' with: 'Smallapack-External-nice.23';
			package: 'Smallapack-Matrix' with: 'Smallapack-Matrix-nice.27';
			package: 'Smallapack-AlgorithmPrereq' with: 'Smallapack-AlgorithmPrereq-nice.1';
			package: 'Smallapack-Algorithm' with: 'Smallapack-Algorithm-nice.9';
			package: 'Smallapack-SUnitTests' with: 'Smallapack-SUnitTests-nice.12'.].
	spec for: #squeak do: [
		spec
			package: 'Math-Complex-Extensions' with: 'Math-Complex-Extensions-nice.9';
			package: 'Smallapack-Compiler' with:  'Smallapack-Compiler.trunk-nice.6'.
		spec postLoadDoIt: #postLoadInitialization].
	spec for: #pharo do: [
		spec
			package: 'Smallapack-Compiler' with: 'Smallapack-Compiler-nice.5'.
		spec postLoadDoIt: #postLoadInitialization].! !

!ConfigurationOfSmallapack methodsFor: 'versions' stamp: 'nice 8/7/2016 01:46'!
version13: spec
	<version: '1.3' imports: #('1.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Library names are in Preferences'.
		spec author: 'nice'.
		spec timestamp: '2016/07/30 02:00'.
		spec 
			package: 'Smallapack-Collection' with: 'Smallapack-Collection-nice.16';
			package: 'Smallapack-ExternalPrereq' with: 'Smallapack-ExternalPrereq-nice.4';
			package: 'Smallapack-External' with: 'Smallapack-External-nice.25';
			package: 'Smallapack-Matrix' with: 'Smallapack-Matrix-nice.29';
			package: 'Smallapack-AlgorithmPrereq' with: 'Smallapack-AlgorithmPrereq-nice.1';
			package: 'Smallapack-Algorithm' with: 'Smallapack-Algorithm-nice.9';
			package: 'Smallapack-SUnitTests' with: 'Smallapack-SUnitTests-nice.12'.].
	spec for: #squeak do: [
		spec
			package: 'Math-Complex-Extensions' with: 'Math-Complex-Extensions-nice.9';
			package: 'Smallapack-Compiler' with:  'Smallapack-Compiler.trunk-nice.6'.
		spec postLoadDoIt: #postLoadInitialization].
	spec for: #pharo do: [
		spec
			package: 'Smallapack-Compiler' with: 'Smallapack-Compiler-nice.5'.
		spec postLoadDoIt: #postLoadInitialization].! !

!ConfigurationOfSmallapack methodsFor: 'versions' stamp: 'nice 1/9/2019 13:58'!
version14: spec
	<version: '1.4' imports: #('1.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Fix for least square and a few other algorithms'.
		spec author: 'nice'.
		spec timestamp: '2016/08/12 23:50'.
		spec 
			package: 'Smallapack-Collection' with: 'Smallapack-Collection-nice.16';
			package: 'Smallapack-ExternalPrereq' with: 'Smallapack-ExternalPrereq-nice.4';
			package: 'Smallapack-External' with: 'Smallapack-External-nice.25';
			package: 'Smallapack-Matrix' with: 'Smallapack-Matrix-nice.29';
			package: 'Smallapack-AlgorithmPrereq' with: 'Smallapack-AlgorithmPrereq-nice.1';
			package: 'Smallapack-Algorithm' with: 'Smallapack-Algorithm-nice.10';
			package: 'Smallapack-SUnitTests' with: 'Smallapack-SUnitTests-nice.12'.].
	spec for: #squeak do: [
		spec
			package: 'Math-Complex-Extensions' with: 'Math-Complex-Extensions-nice.9';
			package: 'Smallapack-Compiler' with:  'Smallapack-Compiler.trunk-nice.6'.
		spec postLoadDoIt: #postLoadInitialization].
	spec for: #pharo do: [
		spec
			package: 'Smallapack-Compiler' with: 'Smallapack-Compiler-nice.5'.
		spec postLoadDoIt: #postLoadInitialization].
	spec for: #'pharo.3.0.x' do: [
		spec
			package: 'Smallapack-CompilerPharo3Patch' with: 'Smallapack-CompilerPharo3Patch-nice.1'.
		spec postLoadDoIt: #postLoadInitialization].
	spec for: #'pharo.4.0.x' do: [
		spec
			package: 'Smallapack-CompilerPharo3Patch' with: 'Smallapack-CompilerPharo3Patch-nice.1'.
		spec postLoadDoIt: #postLoadInitialization].
	spec for: #'pharo.5.0.x' do: [
		spec
			package: 'Smallapack-CompilerPharo3Patch' with: 'Smallapack-CompilerPharo3Patch-nice.1';
			package: 'Smallapack-EndianPharo5Patch' with: 'Smallapack-EndianPharo5Patch-nice.1'.
		spec postLoadDoIt: #postLoadInitialization].! !

!ConfigurationOfSmallapack methodsFor: 'versions' stamp: 'nice 3/10/2017 21:37'!
version15: spec
	<version: '1.5' imports: #('1.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Introduce Callback required for Schur Decomposition'.
		spec author: 'nice'.
		spec timestamp: '2017/03/10 00:58'.
		spec 
			package: 'Smallapack-Collection' with: 'Smallapack-Collection-nice.16';
			package: 'Smallapack-ExternalPrereq' with: 'Smallapack-ExternalPrereq-nice.4';
			package: 'Smallapack-External' with: 'Smallapack-External-nice.32';
			package: 'Smallapack-Matrix' with: 'Smallapack-Matrix-nice.30';
			package: 'Smallapack-AlgorithmPrereq' with: 'Smallapack-AlgorithmPrereq-nice.1';
			package: 'Smallapack-Algorithm' with: 'Smallapack-Algorithm-nice.11';
			package: 'Smallapack-SUnitTests' with: 'Smallapack-SUnitTests-nice.12'.].
	spec for: #squeak do: [
		spec
			package: 'Math-Complex-Extensions' with: 'Math-Complex-Extensions-nice.9';
			package: 'Smallapack-Compiler' with:  'Smallapack-Compiler.trunk-nice.6'.
		spec postLoadDoIt: #postLoadInitialization].
	spec for: #pharo do: [
		spec
			package: 'Smallapack-Compiler' with: 'Smallapack-Compiler-nice.5'.
		spec postLoadDoIt: #postLoadInitialization].! !
